@@ -11,6 +11,7 @@
 #include <QtCore/QHashFunctions>
 #include <QtCore/QLatin1String>
 #include <QtCore/QUrl>
+#include <QtCore/QFuture>
 
 #include <memory>
 #include <optional>
@@ -88,6 +89,27 @@ inline bool alarmX(bool alarmCondition, const auto& msg,
 #define QUO_CHECK(...) \
     !::Quotient::alarmX(!(__VA_ARGS__) ? true : false, "Failing expression: " #__VA_ARGS__)
 
+//! A substitute for QtFuture::makeReadyVoidFuture() for compatibility with Qt pre-6.6
+inline auto makeReadyVoidFuture()
+{
+#if QT_VERSION >= QT_VERSION_CHECK(6, 6, 0)
+    return QtFuture::makeReadyVoidFuture();
+#else
+    return QtFuture::makeReadyFuture<void>();
+#endif
+}
+
+//! A substitute for QtFuture::makeReadyValueFuture() for compatibility with Qt pre-6.6
+template <typename T>
+inline auto makeReadyValueFuture(T&& value)
+{
+#if QT_VERSION >= QT_VERSION_CHECK(6, 6, 0)
+    return QtFuture::makeReadyValueFuture(std::forward<T>(value));
+#else
+    return QtFuture::makeReadyFuture(std::forward<T>(value));
+#endif
+}
+
 #if Quotient_VERSION_MAJOR == 0 && Quotient_VERSION_MINOR < 10
 /// This is only to make UnorderedMap alias work until we get rid of it
 template <typename T>
@@ -140,10 +162,8 @@ private:
 
 namespace _impl {
     template <typename T>
-    concept Holds_NonConst_LValue_Ref = requires {
-        std::is_lvalue_reference_v<T>;
-        !std::is_const_v<std::remove_reference<T>>;
-    };
+    concept Holds_NonConst_LValue_Ref =
+        std::is_lvalue_reference_v<T> && !std::is_const_v<std::remove_reference<T>>;
 }
 
 //! \brief An adaptor for Qt (hash-)maps to make them iterable in STL style
